@@ -1,7 +1,7 @@
 /*---------------------------------------------------------------------------*
   C MODULE  cf_ip6_addr_p.c
 
-  Copyright (c) 2003-2004, James H. Woodyatt
+  Copyright (c) 2003-2005, James H. Woodyatt
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -153,7 +153,7 @@ static unsigned long cf_ip6_addr_deserialize(void* bufferPtr)
 }
 
 static struct custom_operations cf_ip6_addr_op = {
-    "org.conjury.pagoda.cf.in6_addr",
+    "org.conjury.ocnae.cf.in6_addr",
     custom_finalize_default,
     cf_ip6_addr_compare,
     cf_ip6_addr_hash,
