@@ -1,7 +1,7 @@
 (*---------------------------------------------------------------------------*
-  IMPLEMENTATION  cf_rbt.ml
+  IMPLEMENTATION  cf_rbtree.ml
 
-  Copyright (c) 2004, James H. Woodyatt
+  Copyright (c) 2004-2005, James H. Woodyatt
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -357,24 +357,104 @@ module Core(N: Node_T) = struct
         with
         | Not_found ->
             u
+
+    let rec of_list_aux_ acc = function
+        | hd :: tl -> of_list_aux_ (replace hd acc) tl
+        | [] -> acc
     
-    let of_list =
-        let rec loop acc = function
-            | hd :: tl -> loop (replace hd acc) tl
-            | [] -> acc
+    let of_list s = of_list_aux_ nil s
+    
+    let rec of_seq_aux_ acc seq =
+        match Lazy.force seq with
+        | Cf_seq.P (hd, tl) -> of_seq_aux_ (replace hd acc) tl
+        | Cf_seq.Z -> acc
+    
+    let of_seq z = of_seq_aux_ nil z
+    
+    type 'a digit_t =
+        | Y of 'a node_t * 'a
+        | X of 'a node_t * 'a * 'a node_t * 'a
+
+    let rec accum_incr_ n x = function
+        | [] -> [ Y (n, x) ]
+        | Y (m, y) :: t -> X (m, y, n, x) :: t
+        | X (m, y, p, z) :: t -> Y (n, x) :: (accum_incr_ (B (y, m, p)) z t)
+
+    let rec accum_decr_ n x = function
+        | [] -> [ Y (n, x) ]
+        | Y (m, y) :: t -> X (n, x, m, y) :: t
+        | X (p, z, m, y) :: t -> Y (n, x) :: (accum_decr_ (B (y, p, m)) z t)
+    
+    let rec final_incr_ acc = function
+        | [] -> acc
+        | Y (m, y) :: t -> final_incr_ (B (y, m, acc)) t
+        | X (m, y, p, z) :: t -> final_incr_ (B (y, m, R (z, p, acc))) t
+    
+    let rec final_decr_ acc = function
+        | [] -> acc
+        | Y (m, y) :: t -> final_decr_ (B (y, acc, m)) t
+        | X (p, z, m, y) :: t -> final_decr_ (B (y, R (z, acc, p), m)) t
+
+    let of_list_incr =
+        let rec loop last acc = function
+            | hd :: tl -> 
+                if N.compare last hd > 0 then
+                    of_list_aux_ (replace hd (final_incr_ Z acc)) tl
+                else
+                    loop hd (accum_incr_ Z hd acc) tl
+            | [] ->
+                final_incr_ Z acc
+        in
+        function
+        | [] -> Z
+        | hd :: tl -> loop hd [ Y (Z, hd) ] tl
+
+    let of_list_decr =
+        let rec loop last acc = function
+            | hd :: tl -> 
+                if N.compare last hd < 0 then
+                    of_list_aux_ (replace hd (final_decr_ Z acc)) tl
+                else
+                    loop hd (accum_decr_ Z hd acc) tl
+            | [] ->
+                final_incr_ Z acc
+        in
+        function
+        | [] -> Z
+        | hd :: tl -> loop hd [ Y (Z, hd) ] tl
+
+    let of_seq_incr =
+        let rec loop last acc z =
+            match Lazy.force z with
+            | Cf_seq.P (hd, tl) -> 
+                if N.compare last hd > 0 then
+                    of_seq_aux_ (replace hd (final_incr_ Z acc)) tl
+                else
+                    loop hd (accum_incr_ Z hd acc) tl
+            | Cf_seq.Z ->
+                final_incr_ Z acc
         in
         fun z ->
-            loop nil z
-    
-    let of_seq =
-        let rec loop acc seq =
-            match Lazy.force seq with
-            | Cf_seq.P (hd, tl) -> loop (replace hd acc) tl
-            | Cf_seq.Z -> acc
-        in
-        fun seq ->
-            loop nil seq
+            match Lazy.force z with
+            | Cf_seq.Z -> Z
+            | Cf_seq.P (hd, tl) -> loop hd [ Y (Z, hd) ] tl
 
+    let of_seq_decr =
+        let rec loop last acc z =
+            match Lazy.force z with
+            | Cf_seq.P (hd, tl) -> 
+                if N.compare last hd < 0 then
+                    of_seq_aux_ (replace hd (final_decr_ Z acc)) tl
+                else
+                    loop hd (accum_decr_ Z hd acc) tl
+            | Cf_seq.Z ->
+                final_decr_ Z acc
+        in
+        fun z ->
+            match Lazy.force z with
+            | Cf_seq.Z -> Z
+            | Cf_seq.P (hd, tl) -> loop hd [ Y (Z, hd) ] tl
+    
     type 'a stack_t = ('a * 'a node_t) list
     
     let rec stack_min_ i = function
@@ -767,7 +847,7 @@ module Map(K: Cf_ordered.Total_T) = struct
             end
             else begin
                 let _, y = y in
-                s, Some y
+                R (x, a, b), Some y
             end
         | B (y, a, b) as s ->
             let d = N.compare x y in
@@ -781,7 +861,7 @@ module Map(K: Cf_ordered.Total_T) = struct
             end
             else begin
                 let _, y = y in
-                s, Some y
+                R (x, a, b), Some y
             end
 
     let insert x u =
@@ -803,4 +883,4 @@ module Map(K: Cf_ordered.Total_T) = struct
                 dup_color_ (N.cons key (f (N.obj x))) a b u
 end
 
-(*--- End of File [ cf_rbt.ml ] ---*)
+(*--- End of File [ cf_rbtree.ml ] ---*)
