@@ -1,7 +1,7 @@
 /*---------------------------------------------------------------------------*
   C MODULE  cf_socket_p.c
 
-  Copyright (c) 2003-2004, James H. Woodyatt
+  Copyright (c) 2003-2005, James H. Woodyatt
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -63,7 +63,7 @@ static long cf_socket_domain_hash(value v)
 }
 
 static struct custom_operations cf_socket_domain_op = {
-    "org.conjury.pagoda.cf.socket_domain",
+    "org.conjury.ocnae.cf.socket_domain",
     custom_finalize_default,
     cf_socket_domain_compare,
     cf_socket_domain_hash,
@@ -84,7 +84,7 @@ static long cf_socket_hash(value v)
 }
 
 static struct custom_operations cf_socket_op = {
-    "org.conjury.pagoda.cf.socket",
+    "org.conjury.ocnae.cf.socket",
     custom_finalize_default,
     cf_socket_compare,
     cf_socket_hash,
@@ -592,7 +592,7 @@ static long cf_socket_option_hash(value v)
 }
 
 static struct custom_operations cf_socket_option_op = {
-    "org.conjury.pagoda.cf.socket_option",
+    "org.conjury.ocnae.cf.socket_option",
     custom_finalize_default,
     cf_socket_option_compare,
     cf_socket_option_hash,
