@@ -1,7 +1,7 @@
 (*---------------------------------------------------------------------------*
   IMPLEMENTATION  cf_uri.ml
 
-  Copyright (c) 2003-2004, James H. Woodyatt
+  Copyright (c) 2003-2005, James H. Woodyatt
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,7 @@
 
 open Cf_flow.Op
 open Cf_parser.Op
-open Cf_lexer.Op
+open Cf_lex.Op
 
 let ch_is_up_alpha_ = function 'A'..'Z' -> true | _ -> false
 let ch_is_dn_alpha_ = function 'a'..'z' -> true | _ -> false
@@ -175,30 +175,30 @@ let escape ?(allow = (fun _ -> false)) =
 let unescape s =
     Cf_seq.to_string (Cf_flow.commute (w_unescape_ ()) (Cf_seq.of_string s))
 
-let p_colon_ s = ?: ':' s
-let p_semicolon_ s = ?: ';' s
-let p_slash_ s = ?: '/' s
-let p_dot_ s = ?: '.' s
-let p_at_ s = ?: '@' s
+let p_colon_ s = ?.':' s
+let p_semicolon_ s = ?.';' s
+let p_slash_ s = ?.'/' s
+let p_dot_ s = ?.'.' s
+let p_at_ s = ?.'@' s
 
 let p_slashslash_ s =
     let m =
-        ?: '/' >>= fun _ ->
-        ?: '/' >>= fun _ ->
+        ?.'/' >>= fun _ ->
+        ?.'/' >>= fun _ ->
         ~:()
     in
     m s
 
-let p_scheme_ = Cf_lexer.create begin
-    x_alpha_ $& !*(x_alpha_ $| x_digit_ $| x_plus_ $| x_hyphen_ $| x_dot_) $^
+let p_scheme_ = Cf_lex.create begin
+    x_alpha_ $& !*(x_alpha_ $| x_digit_ $| x_plus_ $| x_hyphen_ $| x_dot_) $>
     String.lowercase
 end
 
 let p_opaque_part_ =
-    Cf_lexer.create (x_uric_ $& !*x_uric_no_slash_ $^ unescape)
+    Cf_lex.create (x_uric_ $& !*x_uric_no_slash_ $> unescape)
 
 let p_uric_string_ =
-    Cf_lexer.create (!*x_uric_ $^ (fun x -> (x : string)))
+    Cf_lex.create (!*x_uric_ $> (fun x -> (x : string)))
 
 let p_hostname_ =
     let x_label_suffix_ = !*(x_alphanum_ $| x_hyphen_) $& x_alphanum_ in
@@ -207,27 +207,27 @@ let p_hostname_ =
     let x_hostname_ =
         !*(x_domainlabel_ $& x_dot_) $& x_toplabel_ $& !?x_dot_
     in
-    Cf_lexer.create (x_hostname_ $^ String.lowercase)
+    Cf_lex.create (x_hostname_ $> String.lowercase)
 
 let p_ipv4_addr_ =
     let x_num = !+ !^ch_is_digit_ in
     let x_ip4_addr = x_num $& x_num $& x_num $& x_num in
     let action lim s =
-        let s1 = Cf_seq.limit lim (Cf_seq.map fst s) in
+        let s1 = Cf_seq.limit lim s in
         match Cf_ip4_addr.pton (Cf_seq.to_string s1) with
         | Some addr -> Some (addr, Cf_seq.shift lim s)
         | None -> None
         
     in    
-    Cf_lexer.create (x_ip4_addr $@ action)
+    Cf_lex.create (x_ip4_addr $@ action)
 
 type host_t =
     | H_hostname of string
     | H_ip4_addr of Cf_ip4_addr.opaque Cf_ip4_addr.t
 
 let p_userinfo_ =
-    Cf_lexer.create begin
-        x_unreserved_ $| x_escaped_ $| !^ch_is_reserved_in_userinfo_ $^
+    Cf_lex.create begin
+        x_unreserved_ $| x_escaped_ $| !^ch_is_reserved_in_userinfo_ $>
         unescape
     end
 
@@ -241,7 +241,7 @@ type authority_t =
     | A_server of server_t option
     | A_reg_name of string
 
-let p_port_ = Cf_lexer.create ((!* !^ch_is_digit_) $^ int_of_string)
+let p_port_ = Cf_lex.create ((!* !^ch_is_digit_) $> int_of_string)
 
 let p_server_ =
     let p_userinfo_at_ =
@@ -267,8 +267,8 @@ let p_server_ =
     end
 
 let p_reg_name_ =
-    Cf_lexer.create begin
-        !+(x_unreserved_ $| x_escaped_ $| !^ch_is_reserved_in_userinfo_) $^
+    Cf_lex.create begin
+        !+(x_unreserved_ $| x_escaped_ $| !^ch_is_reserved_in_userinfo_) $>
         unescape
     end
 
@@ -277,7 +277,7 @@ let p_authority_ = Cf_parser.alt [
     (p_reg_name_ >>= fun rn -> ~:(A_reg_name rn));
 ]
 
-let p_pchar_star_ = Cf_lexer.create (!* x_pchar_ $^ unescape)
+let p_pchar_star_ = Cf_lex.create (!* x_pchar_ $> unescape)
 
 let p_param_ = p_semicolon_ >>= fun _ -> p_pchar_star_
 
@@ -299,9 +299,9 @@ let p_path_segments_ =
 
 let p_abs_path_ = p_slash_ >>= fun _ -> p_path_segments_ 
 
-let p_rel_segment_no_semi_ = Cf_lexer.create begin
+let p_rel_segment_no_semi_ = Cf_lex.create begin
     let reserved = !^ch_is_reserved_in_rel_segment_no_semi_ in
-    !+ (x_unreserved_ $| x_escaped_ $| reserved) $^ unescape;
+    !+ (x_unreserved_ $| x_escaped_ $| reserved) $> unescape;
 end
 
 let p_rel_segment_nonempty_ =
@@ -346,10 +346,10 @@ type rel_path_v = [ `Rel of segment_t list ]
 
 type path_t = [ net_path_v | abs_path_v | rel_path_v ]
 
-let p_query_ = ?/ (?: '?' >>= fun _ -> p_uric_string_)
+let p_query_ = ?/ (?.'?' >>= fun _ -> p_uric_string_)
 
 let p_fragment_ = ?/ begin
-    ?: '#' >>= fun _ ->
+    ?.'#' >>= fun _ ->
     p_uric_string_ >>= fun frag ->
     ~:(unescape frag)
 end
@@ -503,7 +503,7 @@ let refer_to_base ~base ~rel =
         let hier = { abs_hier_path = path; abs_hier_query = rel.rel_query } in
         { base with abs_special = S_hier hier }
 
-let cursor0_ = new Cf_lexer.cursor 0
+let cursor0_ = new Cf_parser.cursor 0
 
 let p_uri_ = Cf_parser.alt [
     (p_absolute_uri_ >>= fun x -> ~:(A x));
@@ -517,7 +517,7 @@ let message_to_uri =
         ~:x
     in
     fun m ->
-        match p (Cf_parser.X.weave cursor0_ (Cf_message.to_seq m)) with
+        match p (Cf_message.to_seq m) with
         | None -> invalid_arg "Cf_uri.message_to_uri: syntax error"
         | Some (uri, _) -> uri
 
@@ -543,7 +543,7 @@ let message_to_uri_reference =
         ~:x
     in
     fun m ->
-        match p (Cf_parser.X.weave cursor0_ (Cf_message.to_seq m)) with
+        match p (Cf_message.to_seq m) with
         | None -> invalid_arg "Cf_uri.message_to_uri_reference: syntax error"
         | Some (uriref, _) -> uriref
 
